package es.verdnatura.presentation.view.feature.ajustes.model

import es.verdnatura.presentation.view.feature.login.model.Sector

class AjustesItemVO(
    var title: String = "",
    var selected: String? = null,
    var sectorFk: Int? = null,
    var printerFk: Int? = null,
    var printerSelected: String? = null,
    var action: Boolean,
    var holdPosition: Boolean = false
)

class SectorItemVO(
    var id: Int,
    var description: String,
    val warehouseFk: Int?
)

class SectorListVO(
    var list: List<SectorItemVO> = listOf()
)

class PrintersList(
    var list: MutableList<Printers> = mutableListOf()
)

class Printers(
    var id: Int,
    var name: String,
    var sector: Sector?

)

class WorkerPrintersList(
    var list: List<Printers> = listOf()
)

class Train(
    var id: Int,
    var name: String
)

class TrainList(
    var list: List<Train> = listOf()
)